==> knative-model-5.0.2-sources.jar: io/fabric8/knative/sources/v1beta1/SinkBindingBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SinkBindingBuilder extends SinkBindingFluentImpl<SinkBindingBuilder> implements VisitableBuilder<SinkBinding,SinkBindingBuilder> {

    SinkBindingFluent<?> fluent;
    Boolean validationEnabled;

    public SinkBindingBuilder() {
        this(true);
    }

    public SinkBindingBuilder(Boolean validationEnabled) {
        this(new SinkBinding(), validationEnabled);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent) {
        this(fluent, true);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SinkBinding(), validationEnabled);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent,SinkBinding instance) {
        this(fluent, instance, true);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent,SinkBinding instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public SinkBindingBuilder(SinkBinding instance) {
        this(instance,true);
    }

    public SinkBindingBuilder(SinkBinding instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditableSinkBinding build() {
        EditableSinkBinding buildable = new EditableSinkBinding(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SinkBindingBuilder that = (SinkBindingBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/sources/v1beta1/SinkBindingBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SinkBindingBuilder extends SinkBindingFluentImpl<SinkBindingBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<SinkBinding,SinkBindingBuilder> {

    SinkBindingFluent<?> fluent;
    Boolean validationEnabled;

    public SinkBindingBuilder() {
        this(true);
    }

    public SinkBindingBuilder(Boolean validationEnabled) {
        this(new SinkBinding(), validationEnabled);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent) {
        this(fluent, true);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SinkBinding(), validationEnabled);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent,SinkBinding instance) {
        this(fluent, instance, true);
    }

    public SinkBindingBuilder(SinkBindingFluent<?> fluent,SinkBinding instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public SinkBindingBuilder(SinkBinding instance) {
        this(instance,true);
    }

    public SinkBindingBuilder(SinkBinding instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditableSinkBinding build() {
        EditableSinkBinding buildable = new EditableSinkBinding(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SinkBindingBuilder that = (SinkBindingBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
